==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QStyleOptionGraphicsItem_shell.cpp <==
#include "QStyleOptionGraphicsItem_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionGraphicsItem(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionGraphicsItem")
    QStyleOptionGraphicsItem *_ptr = reinterpret_cast<QStyleOptionGraphicsItem *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionGraphicsItem_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionGraphicsItem_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionGraphicsItem_shell) ); }

jmethodID QStyleOptionGraphicsItem_shell::__shell_javaMethod(int pos) const { return QStyleOptionGraphicsItem_shell::__shell()->javaMethod(typeid(QStyleOptionGraphicsItem), pos); }

// emitting (writeShellConstructor)
QStyleOptionGraphicsItem_shell::QStyleOptionGraphicsItem_shell()
    : QStyleOptionGraphicsItem()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem_shell()", QStyleOptionGraphicsItem_shell::__shell())
    QStyleOptionGraphicsItem_shell::__shell()->constructed(typeid(QStyleOptionGraphicsItem));
}

QStyleOptionGraphicsItem_shell::QStyleOptionGraphicsItem_shell(const QStyleOptionGraphicsItem& other0)
    : QStyleOptionGraphicsItem(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem_shell(const QStyleOptionGraphicsItem& other0)", QStyleOptionGraphicsItem_shell::__shell())
    QStyleOptionGraphicsItem_shell::__shell()->constructed(typeid(QStyleOptionGraphicsItem));
}

// emitting (writeShellDestructor)
QStyleOptionGraphicsItem_shell::~QStyleOptionGraphicsItem_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionGraphicsItem::~QStyleOptionGraphicsItem()", QStyleOptionGraphicsItem_shell::__shell())
    QStyleOptionGraphicsItem_shell::__shell()->destructed(typeid(QStyleOptionGraphicsItem));
}

void QStyleOptionGraphicsItem_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionGraphicsItem_shell*>(ptr)->QStyleOptionGraphicsItem_shell::__shell()->tryDeleteShell(typeid(QStyleOptionGraphicsItem));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionGraphicsItem()
void __qt_construct_QStyleOptionGraphicsItem(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionGraphicsItem()")
    Q_UNUSED(__java_arguments)
    QStyleOptionGraphicsItem *__qt_this = new(__qtjambi_ptr) QStyleOptionGraphicsItem_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_initialize_1native__Lio_qt_widgets_QStyleOptionGraphicsItem_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionGraphicsItem, sizeof(QStyleOptionGraphicsItem_shell), typeid(QStyleOptionGraphicsItem), true, &deleter_QStyleOptionGraphicsItem, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
void __qt_construct_QStyleOptionGraphicsItem_cref_QStyleOptionGraphicsItem(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionGraphicsItem& __qt_other0 = qtjambi_cast<const QStyleOptionGraphicsItem& >(__jni_env, other0);
    QStyleOptionGraphicsItem *__qt_this = new(__qtjambi_ptr) QStyleOptionGraphicsItem_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_initialize_1native__Lio_qt_widgets_QStyleOptionGraphicsItem_2Lio_qt_widgets_QStyleOptionGraphicsItem_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionGraphicsItem_cref_QStyleOptionGraphicsItem, sizeof(QStyleOptionGraphicsItem_shell), typeid(QStyleOptionGraphicsItem), true, &deleter_QStyleOptionGraphicsItem, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionGraphicsItem_shell
void __qt_destruct_QStyleOptionGraphicsItem(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionGraphicsItem")
    reinterpret_cast<QStyleOptionGraphicsItem_shell*>(ptr)->~QStyleOptionGraphicsItem_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionGraphicsItem::operator=(QStyleOptionGraphicsItem)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_assign_1native_1cref_1QStyleOptionGraphicsItem__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionGraphicsItem::operator=(QStyleOptionGraphicsItem)", __qt_this)
        const QStyleOptionGraphicsItem& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionGraphicsItem>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionGraphicsItem::levelOfDetailFromTransform(QTransform)
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_levelOfDetailFromTransform_1native_1cref_1QTransform__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID worldTransform0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionGraphicsItem::levelOfDetailFromTransform(QTransform)")
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QTransform& __qt_worldTransform0 = QtJambiAPI::valueReferenceFromNativeId<QTransform>(worldTransform0);
        qreal __qt_return_value = QStyleOptionGraphicsItem::levelOfDetailFromTransform(__qt_worldTransform0);
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_setExposedRect_1native_1cref_1QRectF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID exposedRect0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRectF& __qt_exposedRect0 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(exposedRect0);
        __qt_this->exposedRect = __qt_exposedRect0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_exposedRect_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRectF&  __qt_value = __qt_this->exposedRect;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_setLevelOfDetail_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble levelOfDetail0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->levelOfDetail = static_cast<qreal>(levelOfDetail0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_levelOfDetail_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->levelOfDetail;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionGraphicsItem(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionGraphicsItem>("QStyleOptionGraphicsItem", "io/qt/widgets/QStyleOptionGraphicsItem");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionGraphicsItem, {
        ConstructorInfo(&__qt_construct_QStyleOptionGraphicsItem, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionGraphicsItem_cref_QStyleOptionGraphicsItem, "Lio/qt/widgets/QStyleOptionGraphicsItem;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionGraphicsItem);
    registerMetaType<QStyleOptionGraphicsItem>("QStyleOptionGraphicsItem");
    registerSizeOfShell(typeId, sizeof(QStyleOptionGraphicsItem_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionGraphicsItem::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QStyleOptionGraphicsItem_shell.cpp <==
#include "QStyleOptionGraphicsItem_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionGraphicsItem(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionGraphicsItem")
    QStyleOptionGraphicsItem *_ptr = reinterpret_cast<QStyleOptionGraphicsItem *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionGraphicsItem_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionGraphicsItem_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionGraphicsItem_shell) ); }

// emitting (writeShellDestructor)
QStyleOptionGraphicsItem_shell::~QStyleOptionGraphicsItem_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionGraphicsItem::~QStyleOptionGraphicsItem()", this)
    QStyleOptionGraphicsItem_shell::__shell()->destructed(typeid(QStyleOptionGraphicsItem));
}

// emitting (writeShellConstructor)
QStyleOptionGraphicsItem_shell::QStyleOptionGraphicsItem_shell()
    : QStyleOptionGraphicsItem()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem_shell()", this)
    QStyleOptionGraphicsItem_shell::__shell()->constructed(typeid(QStyleOptionGraphicsItem));
}

QStyleOptionGraphicsItem_shell::QStyleOptionGraphicsItem_shell(const QStyleOptionGraphicsItem& other0)
    : QStyleOptionGraphicsItem(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem_shell(const QStyleOptionGraphicsItem& other0)", this)
    QStyleOptionGraphicsItem_shell::__shell()->constructed(typeid(QStyleOptionGraphicsItem));
}

void QStyleOptionGraphicsItem_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionGraphicsItem_shell*>(ptr)->QStyleOptionGraphicsItem_shell::__shell()->tryDeleteShell(typeid(QStyleOptionGraphicsItem));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionGraphicsItem()
void __qt_construct_QStyleOptionGraphicsItem(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionGraphicsItem()")
    Q_UNUSED(__java_arguments)
    QStyleOptionGraphicsItem *__qt_this = new(__qtjambi_ptr) QStyleOptionGraphicsItem_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_initialize_1native__Lio_qt_widgets_QStyleOptionGraphicsItem_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionGraphicsItem, sizeof(QStyleOptionGraphicsItem_shell), typeid(QStyleOptionGraphicsItem), 0, true, &deleter_QStyleOptionGraphicsItem, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
void __qt_construct_QStyleOptionGraphicsItem_cref_QStyleOptionGraphicsItem(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionGraphicsItem& __qt_other0 = qtjambi_cast<const QStyleOptionGraphicsItem&>(__jni_env, other0);
    QStyleOptionGraphicsItem *__qt_this = new(__qtjambi_ptr) QStyleOptionGraphicsItem_shell(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_initialize_1native__Lio_qt_widgets_QStyleOptionGraphicsItem_2Lio_qt_widgets_QStyleOptionGraphicsItem_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionGraphicsItem_cref_QStyleOptionGraphicsItem, sizeof(QStyleOptionGraphicsItem_shell), typeid(QStyleOptionGraphicsItem), 0, true, &deleter_QStyleOptionGraphicsItem, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionGraphicsItem_shell
void __qt_destruct_QStyleOptionGraphicsItem(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionGraphicsItem")
    reinterpret_cast<QStyleOptionGraphicsItem_shell*>(ptr)->~QStyleOptionGraphicsItem_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionGraphicsItem::operator=(QStyleOptionGraphicsItem)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_assign_1native_1cref_1QStyleOptionGraphicsItem__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionGraphicsItem::operator=(QStyleOptionGraphicsItem)", __this_nativeId)
        const QStyleOptionGraphicsItem& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionGraphicsItem>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionGraphicsItem::levelOfDetailFromTransform(QTransform)
extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_levelOfDetailFromTransform_1native_1cref_1QTransform__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID worldTransform0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionGraphicsItem::levelOfDetailFromTransform(QTransform)")
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        const QTransform& __qt_worldTransform0 = QtJambiAPI::valueReferenceFromNativeId<QTransform>(worldTransform0);
        qreal __qt_return_value = QStyleOptionGraphicsItem::levelOfDetailFromTransform(__qt_worldTransform0);
        __java_return_value = jdouble(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_setExposedRect_1native_1cref_1QRectF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID exposedRect0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRectF& __qt_exposedRect0 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(exposedRect0);
        __qt_this->exposedRect = __qt_exposedRect0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_exposedRect_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QRectF&  __qt_value = __qt_this->exposedRect;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionGraphicsItem_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionGraphicsItem *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionGraphicsItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionGraphicsItem(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionGraphicsItem>("QStyleOptionGraphicsItem", "io/qt/widgets/QStyleOptionGraphicsItem");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStyleOptionGraphicsItem, {
        ConstructorInfo(&__qt_construct_QStyleOptionGraphicsItem, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionGraphicsItem_cref_QStyleOptionGraphicsItem, "Lio/qt/widgets/QStyleOptionGraphicsItem;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionGraphicsItem);
    registerMetaType<QStyleOptionGraphicsItem>("QStyleOptionGraphicsItem");
    registerSizeOfShell(typeId, sizeof(QStyleOptionGraphicsItem_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionGraphicsItem::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
